from slippy.core import _AdhesionModelABC

__all__ = ['_AdhesionModel']


class _AdhesionModel(_AdhesionModelABC):
    def __init__(self):
        pass
